@@ -1,32 +1,14 @@
 import json
 import re
-import sys
-from pathlib import Path
+
 import pendulum
 import requests
 from bs4 import BeautifulSoup
+from furl import furl
 
 ABB_URL = 'http://audiobookbay.fi'
 
 
-def update_config(k, v):
-    p = Path('config.json')
-    data = dict()
-    if p.exists():
-        data = json.loads(p.read_text())
-    data[k] = v
-    p.write_text(json.dumps(data))
-    print(f'{p} updated: {k} = {v}')
-
-
-def read_config():
-    p = Path('config.json')
-    data = dict()
-    if p.exists():
-        data = json.loads(p.read_text())
-    return data
-
-
 def get_url(page_num):
     u = ABB_URL.rstrip('/') + '/'
     if page_num > 1:
@@ -74,7 +56,7 @@ def abb_post_to_dict(html):
         file_format = file_format.split('/')[0].strip()
 
     return {
-        'url': url,
+        'url': furl(ABB_URL).join(url),
         'post_title': post_title,
         'post_date': post_date,
         'image_url': image_url,
@@ -114,7 +96,7 @@ class Abb:
             resp = self.session.get(url, timeout=5.0)
         except requests.RequestException as err:
             print(f"Error page {page_num} {url}")
-            # print(str(err))
+            print(err)
             return []
 
         soup = BeautifulSoup(resp.text, 'html.parser')
@@ -134,45 +116,3 @@ def read_pages(start_page, end_page):
         abb.read_page(p)
 
     return abb.all_posts
-
-
-def main() -> None:
-    """Read the Real Python article feed."""
-    args = [a for a in sys.argv[1:] if not a.startswith("-")]
-    opts = [o for o in sys.argv[1:] if o.startswith("-")]
-
-    if len(args) > 1:
-        start = int(args[0])
-        end = int(args[1])
-    elif len(args) == 1:
-        start = 1
-        end = int(args[0]) + 1
-    else:
-        start, end = 1, 5
-    """
-    # Show help message
-    if "-h" in opts or "--help" in opts:
-        viewer.show(__doc__)
-        raise SystemExit()
-
-    # Should links be shown in the text
-    show_links = "-l" in opts or "--show-links" in opts
-
-    # Get URL from config file
-    url = reader.URL
-
-    # An article ID is given, show article
-    if args:
-        for article_id in args:
-            article = feed.get_article(article_id, links=show_links, url=url)
-            viewer.show(article)
-
-    # No ID is given, show list of articles
-    else:
-        site = feed.get_site(url=url)
-        titles = feed.get_titles(url=url)
-        viewer.show_list(site, titles)"""
-
-
-if __name__ == "__main__":
-    main()
